@@ -1,6 +1,6 @@
 package Git::Repository::Plugin::GitHooks;
 # ABSTRACT: A Git::Repository plugin with some goodies for hook developers
-$Git::Repository::Plugin::GitHooks::VERSION = '2.1.1';
+$Git::Repository::Plugin::GitHooks::VERSION = '2.1.2';
 use parent qw/Git::Repository::Plugin/;
 
 use 5.010;
@@ -854,6 +854,11 @@ sub filter_files_in_index {
 sub filter_files_in_range {
     my ($git, $filter, $from, $to) = @_;
 
+    # If $to is he undefined commit this means that a branch or tag is being
+    # removed. In this situation we return the empty list, bacause no file
+    # has been affected.
+    return if $to eq $git->undef_commit;
+
     if ($from eq $git->undef_commit) {
         # If $from is the undefined commit we get the list of commits
         # reachable from $to and not reachable from $from and all other
@@ -1129,7 +1134,7 @@ Git::Repository::Plugin::GitHooks - A Git::Repository plugin with some goodies f
 
 =head1 VERSION
 
-version 2.1.1
+version 2.1.2
 
 =head1 SYNOPSIS
 
